==> aws-android-sdk-kms-2.2.17-sources.jar: com/amazonaws/services/kms/model/KMSInvalidStateException.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.kms.model;

import com.amazonaws.AmazonServiceException;

/**
 * <p>
 * The request was rejected because the state of the specified resource
 * is not valid for this request.
 * </p>
 * <p>
 * For more information about how key state affects the use of a customer
 * master key (CMK), go to
 * <a href="http://docs.aws.amazon.com/kms/latest/developerguide/key-state.html"> How Key State Affects the Use of a Customer Master Key </a>
 * in the <i>AWS Key Management Service Developer Guide</i> .
 * </p>
 */        
public class KMSInvalidStateException extends AmazonServiceException {
    private static final long serialVersionUID = 1L;
    
    /**
     * Constructs a new KMSInvalidStateException with the specified error
     * message.
     * 
     * @param message Describes the error encountered.
     */
    public KMSInvalidStateException(String message) {
        super(message);
    }
    
}

==> aws-android-sdk-kms-2.2.21-sources.jar: com/amazonaws/services/kms/model/KMSInvalidStateException.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kms.model;

import com.amazonaws.AmazonServiceException;

/**
 * <p>
 * The request was rejected because the state of the specified resource is not
 * valid for this request.
 * </p>
 * <p>
 * For more information about how key state affects the use of a customer master
 * key (CMK), see <a
 * href="http://docs.aws.amazon.com/kms/latest/developerguide/key-state.html"
 * >How Key State Affects the Use of a Customer Master Key</a> in the <i>AWS Key
 * Management Service Developer Guide</i>.
 * </p>
 */
public class KMSInvalidStateException extends AmazonServiceException {
    private static final long serialVersionUID = 1L;

    /**
     * Constructs a new KMSInvalidStateException with the specified error
     * message.
     *
     * @param message Describes the error encountered.
     */
    public KMSInvalidStateException(String message) {
        super(message);
    }
}
